Agents
====================
This module implements the fitted Q-iteration algotithm for offline reinforcement learning.

.. code::

   from cfrl import agents

.. automodule:: cfrl.agents
   :members:
   :show-inheritance:
   :special-members: __init__